@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.88';
+  $CPAN::Perl::Releases::VERSION = '0.90';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -331,6 +331,10 @@ our $data =
     "tar.bz2" => "F/FL/FLORA/perl-5.17.5.tar.bz2",
     "tar.gz" => "F/FL/FLORA/perl-5.17.5.tar.gz",
   },
+  "5.17.6" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.17.6.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.17.6.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -439,7 +443,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.88
+version 0.90
 
 =head1 SYNOPSIS
 
